@@ -51,6 +51,30 @@ test_that("reverse works with data frame", {
   )
 })
 
+test_that("reverse works with data frame and append", {
+  test <- data.frame(
+    x = 1:5,
+    y = c(3, 8, 2, 5, 1)
+  )
+  expect_identical(
+    reverse(test, select = "x", append = TRUE),
+    data.frame(
+      x = 1:5,
+      y = c(3, 8, 2, 5, 1),
+      x_r = as.double(5:1)
+    )
+  )
+  expect_identical(
+    reverse(test, append = TRUE),
+    data.frame(
+      x = 1:5,
+      y = c(3, 8, 2, 5, 1),
+      x_r = as.double(5:1),
+      y_r = c(6, 1, 7, 4, 8)
+    )
+  )
+})
+
 test_that("reverse: arg 'select' works with formula", {
   test <- data.frame(
     x = 1:5,
@@ -343,13 +367,13 @@ test_df <- data.frame(
 )
 
 test_that("reverse works with data frames (grouped data)", {
-  skip_if_not_or_load_if_installed("poorman")
+  skip_if_not_installed("poorman")
 
   expect_identical(
     test_df %>%
-      group_by(id) %>%
+      poorman::group_by(id) %>%
       reverse(exclude = "id") %>%
-      ungroup(),
+      poorman::ungroup(),
     data.frame(
       id = rep(c("A", "B"), each = 3),
       value1 = c(10, 10, 3, 6, 2, 3),
@@ -360,6 +384,32 @@ test_that("reverse works with data frames (grouped data)", {
 })
 
 
+test_that("reverse works with grouped data frames and append", {
+  skip_if_not_installed("poorman")
+
+  test <- data.frame(
+    x = 1:6,
+    y = c(3, 8, 2, 5, 1, 4),
+    grp = rep(c("a", "b"), 3),
+    stringsAsFactors = FALSE
+  )
+  expect_identical(
+    test %>%
+      poorman::group_by(grp) %>%
+      reverse(append = TRUE) %>%
+      poorman::ungroup(),
+    data.frame(
+      x = 1:6,
+      y = c(3, 8, 2, 5, 1, 4),
+      grp = rep(c("a", "b"), 3),
+      x_r = as.double(c(5, 6, 3, 4, 1, 2)),
+      y_r = as.double(c(1, 4, 2, 7, 3, 8)),
+      stringsAsFactors = FALSE
+    )
+  )
+})
+
+
 set.seed(789)
 value1 <- sample(c(1:10, NA), 6, replace = TRUE)
 set.seed(10)
@@ -373,13 +423,13 @@ test_df <- data.frame(
 )
 
 test_that("reverse works with data frames containing NAs (grouped data)", {
-  skip_if_not_or_load_if_installed("poorman")
+  skip_if_not_installed("poorman")
 
   expect_identical(
     test_df %>%
-      group_by(id) %>%
+      poorman::group_by(id) %>%
       reverse(exclude = "id") %>%
-      ungroup(),
+      poorman::ungroup(),
     data.frame(
       id = rep(c("A", "B"), each = 3),
       value1 = c(10, 4, 4, 5, 3, 4),
